@@ -1,4 +1,4 @@
-/* $Id: ssh_global.h,v 1.1.4.1 2000/08/25 09:32:09 tls Exp $ */
+/* $Id: ssh_global.h,v 1.5 2000/09/22 01:19:02 andrew Exp $ */
 
 /*
  * Copyright 1999 RedBack Networks, Incorporated.
@@ -16,15 +16,11 @@
 #ifndef _SSH_GLOBAL_H
 #define _SSH_GLOBAL_H
 
-struct sshd_context;
 struct ssh_cipher;
 
-extern int g_argc;
-extern char **g_argv;
-
 extern int exitflag;
 extern int nodaemon;
-extern struct sshd_context g_context;
+extern ssh_context_t g_context;
 extern struct ssh_cipher g_cipher;
 
 #endif _SSH_GLOBAL_H
